# -*- coding: utf-8 -*-
'''
    slashcommands
    =====
    A tiny framework for slash commands of Slack.

    Repository: https://github.com/matsub/slashcommands
    License: MIT
'''

__author__ = 'matsub'
__version__ = '0.2'
__license__ = 'MIT'

from .slashcommands import SlashCommands
